Package: babelmixr2
Type: Package
Title: Use 'nlmixr2' to Interact with Open Source and Commercial
        Software
Version: 0.1.11
Authors@R: c(person("Matthew","Fidler", role = c("aut", "cre"), email = "matthew.fidler@gmail.com", comment=c(ORCID="0000-0001-8538-6691")),
           person("Bill", "Denney", email="wdenney@humanpredictions.com", role="aut", comment=c(ORCID="0000-0002-5759-428X")),
           person("Theodoros", "Papathanasiou",  role="ctb"),
           person("Nook", "Fulloption", role="ctb", comment="goldfish art"))
Description: Run other estimation and simulation software via the 'nlmixr2' (Fidler et al (2019)
  <doi:10.1002/psp4.12445>) interface including 'PKNCA', 'NONMEM' and 'Monolix'. While not required, you can
  get/install the 'lixoftConnectors' package in the 'Monolix' installation, as
  described at the following url
  <https://monolixsuite.slp-software.com/r-functions/2024R1/installation-and-initialization>. When
  'lixoftConnectors' is available, 'Monolix' can be run directly instead of setting up
  command line usage.
License: GPL (>= 3)
URL: https://nlmixr2.github.io/babelmixr2/,
        https://github.com/nlmixr2/babelmixr2/
NeedsCompilation: yes
Encoding: UTF-8
Suggests: testthat, withr, lixoftConnectors, PKNCA (>= 0.10.0),
        rmarkdown, spelling, PopED, units (>= 0.8-6), nlme, dplyr,
        devtools, memoise, FME, coda, crayon
Depends: R (>= 3.5)
Imports: checkmate, cli, digest, lotri, nlmixr2data, nlmixr2extra,
        nlmixr2plot, magrittr, nlmixr2est (>= 4.1.0), nonmem2rx (>=
        0.1.5), monolix2rx (>= 0.0.3), methods, qs2, rex, rxode2 (>=
        4.1.0)
RoxygenNote: 7.3.2
Config/testthat/edition: 3
LinkingTo: Rcpp, rxode2, RcppArmadillo, RcppEigen
Language: en-US
Packaged: 2025-11-27 17:17:09 UTC; matt
Author: Matthew Fidler [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8538-6691>),
  Bill Denney [aut] (ORCID: <https://orcid.org/0000-0002-5759-428X>),
  Theodoros Papathanasiou [ctb],
  Nook Fulloption [ctb] (goldfish art)
Maintainer: Matthew Fidler <matthew.fidler@gmail.com>
Repository: CRAN
Date/Publication: 2025-11-28 13:00:30 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 14:03:11 UTC; unix
Archs: babelmixr2.so.dSYM
