# Generated by roxygen2: do not edit by hand

S3method(as.nlmixr2,default)
S3method(as.nlmixr2,monolix2rx)
S3method(as.nlmixr2,nonmem2rx)
S3method(getValidNlmixrCtl,monolix)
S3method(getValidNlmixrCtl,nonmem)
S3method(getValidNlmixrCtl,pknca)
S3method(getValidNlmixrCtl,poped)
S3method(nlmixr2,pkncaEst)
S3method(nlmixr2Est,monolix)
S3method(nlmixr2Est,nonmem)
S3method(nlmixr2Est,pknca)
S3method(nlmixr2Est,poped)
S3method(nmGetDistributionMonolixLines,default)
S3method(nmGetDistributionMonolixLines,norm)
S3method(nmGetDistributionMonolixLines,rxUi)
S3method(nmGetDistributionMonolixLines,t)
S3method(nmGetDistributionNonmemLines,default)
S3method(nmGetDistributionNonmemLines,norm)
S3method(nmGetDistributionNonmemLines,rxUi)
S3method(nmGetDistributionNonmemLines,t)
S3method(nmObjGetControl,monolix)
S3method(nmObjGetControl,monolix2rx)
S3method(nmObjGetControl,nonmem)
S3method(nmObjGetControl,nonmem2rx)
S3method(nmObjGetFoceiControl,monolix)
S3method(nmObjHandleControlObject,monolixControl)
S3method(nmObjHandleControlObject,nonmemControl)
S3method(print,babelmixr2popedScript)
S3method(print,pkncaEst)
S3method(rxUiGet,mlxtran)
S3method(rxUiGet,mlxtranDatafile)
S3method(rxUiGet,mlxtranFit)
S3method(rxUiGet,mlxtranModel)
S3method(rxUiGet,mlxtranModelCovariate)
S3method(rxUiGet,mlxtranModelIndividual)
S3method(rxUiGet,mlxtranModelLongitudinal)
S3method(rxUiGet,mlxtranMonolix)
S3method(rxUiGet,mlxtranParameter)
S3method(rxUiGet,monolixCovariance)
S3method(rxUiGet,monolixCovarianceEstimatesLin)
S3method(rxUiGet,monolixCovarianceEstimatesSA)
S3method(rxUiGet,monolixCvParam)
S3method(rxUiGet,monolixDataFile)
S3method(rxUiGet,monolixEtaObf)
S3method(rxUiGet,monolixExportPath)
S3method(rxUiGet,monolixFullTheta)
S3method(rxUiGet,monolixHasChartData)
S3method(rxUiGet,monolixIndividualLL)
S3method(rxUiGet,monolixIndividualParameters)
S3method(rxUiGet,monolixIniDf)
S3method(rxUiGet,monolixJacobian)
S3method(rxUiGet,monolixLL)
S3method(rxUiGet,monolixMlxtranFile)
S3method(rxUiGet,monolixModel)
S3method(rxUiGet,monolixModelFileName)
S3method(rxUiGet,monolixModelHashFileName)
S3method(rxUiGet,monolixModelName)
S3method(rxUiGet,monolixObjf)
S3method(rxUiGet,monolixObjfType)
S3method(rxUiGet,monolixOmega)
S3method(rxUiGet,monolixOutputVersion)
S3method(rxUiGet,monolixParHistory)
S3method(rxUiGet,monolixParHistoryRaw)
S3method(rxUiGet,monolixPopulationParameters)
S3method(rxUiGet,monolixPreds)
S3method(rxUiGet,monolixQs)
S3method(rxUiGet,monolixRunLock)
S3method(rxUiGet,monolixTheta)
S3method(rxUiGet,nonmemCcontra)
S3method(rxUiGet,nonmemCcontraName)
S3method(rxUiGet,nonmemContra)
S3method(rxUiGet,nonmemContraName)
S3method(rxUiGet,nonmemCov)
S3method(rxUiGet,nonmemCovFile)
S3method(rxUiGet,nonmemCovariance)
S3method(rxUiGet,nonmemCsv)
S3method(rxUiGet,nonmemErrF)
S3method(rxUiGet,nonmemEst)
S3method(rxUiGet,nonmemEtaObf)
S3method(rxUiGet,nonmemEtaTableName)
S3method(rxUiGet,nonmemExportPath)
S3method(rxUiGet,nonmemExt)
S3method(rxUiGet,nonmemFullTheta)
S3method(rxUiGet,nonmemHashFile)
S3method(rxUiGet,nonmemIniDf)
S3method(rxUiGet,nonmemInput)
S3method(rxUiGet,nonmemLst)
S3method(rxUiGet,nonmemMod)
S3method(rxUiGet,nonmemModel)
S3method(rxUiGet,nonmemModelName)
S3method(rxUiGet,nonmemNmctl)
S3method(rxUiGet,nonmemNmlst)
S3method(rxUiGet,nonmemObjf)
S3method(rxUiGet,nonmemObjfType)
S3method(rxUiGet,nonmemOmega)
S3method(rxUiGet,nonmemOutputExt)
S3method(rxUiGet,nonmemOutputLst)
S3method(rxUiGet,nonmemOutputOmega)
S3method(rxUiGet,nonmemOutputVersion)
S3method(rxUiGet,nonmemParHistory)
S3method(rxUiGet,nonmemPkDesErr0)
S3method(rxUiGet,nonmemPreds)
S3method(rxUiGet,nonmemQs)
S3method(rxUiGet,nonmemRoundingErrors)
S3method(rxUiGet,nonmemRunTime)
S3method(rxUiGet,nonmemSdTableName)
S3method(rxUiGet,nonmemSub)
S3method(rxUiGet,nonmemSuccessful)
S3method(rxUiGet,nonmemTable)
S3method(rxUiGet,nonmemTermMessage)
S3method(rxUiGet,nonmemTheta)
S3method(rxUiGet,nonmemThetaDf)
S3method(rxUiGet,nonmemThetaRep)
S3method(rxUiGet,nonmemTransMessage)
S3method(rxUiGet,nonmemXml)
S3method(rxUiGet,popedBpop)
S3method(rxUiGet,popedBpopRep)
S3method(rxUiGet,popedCovd)
S3method(rxUiGet,popedD)
S3method(rxUiGet,popedFErrorFun)
S3method(rxUiGet,popedFfFun)
S3method(rxUiGet,popedFgFun)
S3method(rxUiGet,popedFullRxModel)
S3method(rxUiGet,popedGetEventFun)
S3method(rxUiGet,popedNotfixedBpop)
S3method(rxUiGet,popedNotfixedCovd)
S3method(rxUiGet,popedNotfixedD)
S3method(rxUiGet,popedNotfixedSigma)
S3method(rxUiGet,popedOptsw)
S3method(rxUiGet,popedParameters)
S3method(rxUiGet,popedRxmodelBase)
S3method(rxUiGet,popedScriptBeforeCtl)
S3method(rxUiGet,popedSettings)
S3method(rxUiGet,popedSigma)
export("%>%")
export("ini<-")
export("model<-")
export(.fmeMcmcF)
export(.minfo)
export(.nlmixrNlmeFun)
export(.popedCluster)
export(.popedF)
export(.popedFree)
export(.popedRxRunSetup)
export(.popedSolveIdME)
export(.popedSolveIdME2)
export(.popedW)
export(.pseudoOptimF)
export(ACF)
export(RxODE)
export(VarCorr)
export(add.dosing)
export(add.sampling)
export(addCwres)
export(addNpde)
export(addTable)
export(as.nlmixr)
export(as.nlmixr2)
export(as.nonmem2rx)
export(augPred)
export(babel.poped.database)
export(babelBpopIdx)
export(bblDatToMonolix)
export(bblDatToMrgsolve)
export(bblDatToNonmem)
export(bblDatToPknca)
export(bblDatToRxode)
export(bobyqaControl)
export(bootplot)
export(bootstrapFit)
export(et)
export(etExpand)
export(eventTable)
export(expit)
export(fixed.effects)
export(fixef)
export(fmeMcmcControl)
export(foceiControl)
export(geom_amt)
export(geom_cens)
export(getData)
export(getStandardColNames)
export(getValidNlmixrCtl)
export(getVarCov)
export(groupedData)
export(ini)
export(lbfgsb3cControl)
export(logit)
export(lotri)
export(mlxtran)
export(model)
export(modelUnitConversion)
export(monolix2rx)
export(monolixControl)
export(n1qn1Control)
export(newuoaControl)
export(nlmControl)
export(nlme)
export(nlmeControl)
export(nlminbControl)
export(nlmixr)
export(nlmixr2)
export(nlmixr2AllEst)
export(nlmixr2Est)
export(nlmixr2NlmeControl)
export(nlsControl)
export(nmGetDistributionMonolixLines)
export(nmGetDistributionNonmemLines)
export(nmObjGetControl)
export(nmObjGetFoceiControl)
export(nmObjHandleControlObject)
export(nmcov)
export(nmext)
export(nminfo)
export(nmtab)
export(nmxml)
export(nonmem2rx)
export(nonmemControl)
export(optimControl)
export(pdBlocked)
export(pdCompSymm)
export(pdConstruct)
export(pdDiag)
export(pdFactor)
export(pdIdent)
export(pdLogChol)
export(pdMat)
export(pdMatrix)
export(pdNatural)
export(pdSymm)
export(pkncaControl)
export(popedControl)
export(popedGetMultipleEndpointModelingTimes)
export(popedMultipleEndpointIndexDataFrame)
export(popedMultipleEndpointParam)
export(popedMultipleEndpointResetTimeIndex)
export(preconditionFit)
export(probit)
export(probitInv)
export(profileFixed)
export(profileFixedSingle)
export(profileLlp)
export(pseudoOptimControl)
export(random.effects)
export(ranef)
export(reStruct)
export(rxCat)
export(rxClean)
export(rxControl)
export(rxDerived)
export(rxFun)
export(rxModelVars)
export(rxParam)
export(rxParams)
export(rxSetPipingAuto)
export(rxSetSeed)
export(rxSolve)
export(rxToMonolix)
export(rxToNonmem)
export(rxUiGet)
export(rxode)
export(rxode2)
export(saemControl)
export(setOfv)
export(simplifyUnit)
export(stat_amt)
export(stat_cens)
export(tableControl)
export(traceplot)
export(uobyqaControl)
export(varComb)
export(varConstPower)
export(varExp)
export(varFixed)
export(varFunc)
export(varIdent)
export(varPower)
export(varWeights)
export(vpcCens)
export(vpcCensTad)
export(vpcPlot)
export(vpcPlotTad)
export(vpcSim)
import(nlmixr2data)
import(nlmixr2plot)
importFrom(lotri,lotri)
importFrom(magrittr,`%>%`)
importFrom(methods,is)
importFrom(monolix2rx,mlxtran)
importFrom(monolix2rx,monolix2rx)
importFrom(nlmixr2est,.nlmixrNlmeFun)
importFrom(nlmixr2est,ACF)
importFrom(nlmixr2est,VarCorr)
importFrom(nlmixr2est,addCwres)
importFrom(nlmixr2est,addNpde)
importFrom(nlmixr2est,addTable)
importFrom(nlmixr2est,augPred)
importFrom(nlmixr2est,bobyqaControl)
importFrom(nlmixr2est,fixed.effects)
importFrom(nlmixr2est,fixef)
importFrom(nlmixr2est,foceiControl)
importFrom(nlmixr2est,getData)
importFrom(nlmixr2est,getValidNlmixrCtl)
importFrom(nlmixr2est,getVarCov)
importFrom(nlmixr2est,groupedData)
importFrom(nlmixr2est,lbfgsb3cControl)
importFrom(nlmixr2est,n1qn1Control)
importFrom(nlmixr2est,newuoaControl)
importFrom(nlmixr2est,nlmControl)
importFrom(nlmixr2est,nlme)
importFrom(nlmixr2est,nlmeControl)
importFrom(nlmixr2est,nlminbControl)
importFrom(nlmixr2est,nlmixr)
importFrom(nlmixr2est,nlmixr2)
importFrom(nlmixr2est,nlmixr2AllEst)
importFrom(nlmixr2est,nlmixr2Est)
importFrom(nlmixr2est,nlmixr2NlmeControl)
importFrom(nlmixr2est,nlsControl)
importFrom(nlmixr2est,nmObjGetControl)
importFrom(nlmixr2est,nmObjGetFoceiControl)
importFrom(nlmixr2est,nmObjHandleControlObject)
importFrom(nlmixr2est,optimControl)
importFrom(nlmixr2est,pdBlocked)
importFrom(nlmixr2est,pdCompSymm)
importFrom(nlmixr2est,pdConstruct)
importFrom(nlmixr2est,pdDiag)
importFrom(nlmixr2est,pdFactor)
importFrom(nlmixr2est,pdIdent)
importFrom(nlmixr2est,pdLogChol)
importFrom(nlmixr2est,pdMat)
importFrom(nlmixr2est,pdMatrix)
importFrom(nlmixr2est,pdNatural)
importFrom(nlmixr2est,pdSymm)
importFrom(nlmixr2est,random.effects)
importFrom(nlmixr2est,ranef)
importFrom(nlmixr2est,reStruct)
importFrom(nlmixr2est,saemControl)
importFrom(nlmixr2est,setOfv)
importFrom(nlmixr2est,tableControl)
importFrom(nlmixr2est,uobyqaControl)
importFrom(nlmixr2est,varComb)
importFrom(nlmixr2est,varConstPower)
importFrom(nlmixr2est,varExp)
importFrom(nlmixr2est,varFixed)
importFrom(nlmixr2est,varFunc)
importFrom(nlmixr2est,varIdent)
importFrom(nlmixr2est,varPower)
importFrom(nlmixr2est,varWeights)
importFrom(nlmixr2est,vpcSim)
importFrom(nlmixr2extra,bootplot)
importFrom(nlmixr2extra,bootstrapFit)
importFrom(nlmixr2extra,preconditionFit)
importFrom(nlmixr2extra,profileFixed)
importFrom(nlmixr2extra,profileFixedSingle)
importFrom(nlmixr2extra,profileLlp)
importFrom(nlmixr2plot,traceplot)
importFrom(nlmixr2plot,vpcCens)
importFrom(nlmixr2plot,vpcCensTad)
importFrom(nlmixr2plot,vpcPlot)
importFrom(nlmixr2plot,vpcPlotTad)
importFrom(nonmem2rx,as.nonmem2rx)
importFrom(nonmem2rx,nmcov)
importFrom(nonmem2rx,nmext)
importFrom(nonmem2rx,nminfo)
importFrom(nonmem2rx,nmtab)
importFrom(nonmem2rx,nmxml)
importFrom(nonmem2rx,nonmem2rx)
importFrom(rxode2,.minfo)
importFrom(rxode2,RxODE)
importFrom(rxode2,`ini<-`)
importFrom(rxode2,`model<-`)
importFrom(rxode2,add.dosing)
importFrom(rxode2,add.sampling)
importFrom(rxode2,et)
importFrom(rxode2,etExpand)
importFrom(rxode2,eventTable)
importFrom(rxode2,expit)
importFrom(rxode2,geom_amt)
importFrom(rxode2,geom_cens)
importFrom(rxode2,ini)
importFrom(rxode2,logit)
importFrom(rxode2,lotri)
importFrom(rxode2,model)
importFrom(rxode2,probit)
importFrom(rxode2,probitInv)
importFrom(rxode2,rxCat)
importFrom(rxode2,rxClean)
importFrom(rxode2,rxControl)
importFrom(rxode2,rxDerived)
importFrom(rxode2,rxFun)
importFrom(rxode2,rxModelVars)
importFrom(rxode2,rxParam)
importFrom(rxode2,rxParams)
importFrom(rxode2,rxSetPipingAuto)
importFrom(rxode2,rxSetSeed)
importFrom(rxode2,rxSolve)
importFrom(rxode2,rxUiGet)
importFrom(rxode2,rxode)
importFrom(rxode2,rxode2)
importFrom(rxode2,stat_amt)
importFrom(rxode2,stat_cens)
importFrom(stats,approxfun)
importFrom(stats,cov)
importFrom(stats,cov2cor)
importFrom(stats,dlnorm)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,na.fail)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,setNames)
importFrom(utils,assignInMyNamespace)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
useDynLib(babelmixr2, .registration=TRUE)
